@@ -536,9 +536,19 @@ void PackageKitUpdater::finished(PackageKit::Transaction::Exit exit, uint /*time
 
     if (!cancel && simulate) {
         auto toremoveOrig = m_packagesModified.value(PackageKit::Transaction::InfoRemoving);
+#ifdef QPK_CHECK_VERSION
+#if QPK_CHECK_VERSION(1, 1, 2)
+        toremoveOrig += m_packagesModified.value(PackageKit::Transaction::InfoRemove);
+#endif
+#endif
         auto toremove = toremoveOrig;
         auto toinstall = QStringList() << m_packagesModified.value(PackageKit::Transaction::InfoInstalling)
                                        << m_packagesModified.value(PackageKit::Transaction::InfoUpdating);
+#ifdef QPK_CHECK_VERSION
+#if QPK_CHECK_VERSION(1, 1, 2)
+        toinstall << m_packagesModified.value(PackageKit::Transaction::InfoInstall);
+#endif
+#endif
 
         // some backends will treat upgrades as removal + install, which makes for terrible error messages.
         for (auto it = toremove.begin(), itEnd = toremove.end(); it != itEnd;) {
