@@ -18,6 +18,8 @@
 #include <QUrl>
 #include <QVector>
 
+#include <ReviewsBackend/Rating.h>
+
 #include "PackageState.h"
 #include "discovercommon_export.h"
 
@@ -25,6 +27,27 @@ class Category;
 class Rating;
 class AbstractResourcesBackend;
 
+struct Screenshot {
+    Screenshot(const QUrl &screenshot)
+        : thumbnail(screenshot)
+        , screenshot(screenshot)
+    {
+    }
+
+    Screenshot(const QUrl &thumbnail, const QUrl &screenshot, bool isAnimated)
+        : thumbnail(thumbnail)
+        , screenshot(screenshot)
+        , isAnimated(isAnimated)
+    {
+    }
+
+    QUrl thumbnail;
+    QUrl screenshot;
+    bool isAnimated = false;
+};
+
+using Screenshots = QVector<Screenshot>;
+
 /**
  * \class AbstractResource  AbstractResource.h "AbstractResource.h"
  *
@@ -60,8 +83,8 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
     Q_PROPERTY(QString availableVersion READ availableVersion NOTIFY versionsChanged)
     Q_PROPERTY(QString section READ section CONSTANT)
     Q_PROPERTY(QStringList mimetypes READ mimetypes CONSTANT)
-    Q_PROPERTY(QObject *backend READ backendObject CONSTANT)
-    Q_PROPERTY(QVariant rating READ ratingVariant NOTIFY ratingFetched)
+    Q_PROPERTY(AbstractResourcesBackend *backend READ backend CONSTANT)
+    Q_PROPERTY(Rating rating READ rating NOTIFY ratingFetched)
     Q_PROPERTY(QString appstreamId READ appstreamId CONSTANT)
     Q_PROPERTY(QUrl url READ url CONSTANT)
     Q_PROPERTY(QString executeLabel READ executeLabel CONSTANT)
@@ -75,6 +98,12 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
     Q_PROPERTY(QString contentRatingDescription READ contentRatingDescription CONSTANT)
     Q_PROPERTY(ContentIntensity contentRatingIntensity READ contentRatingIntensity CONSTANT)
     Q_PROPERTY(uint contentRatingMinimumAge READ contentRatingMinimumAge CONSTANT)
+    Q_PROPERTY(QStringList topObjects READ topObjects CONSTANT)
+    Q_PROPERTY(QStringList bottomObjects READ bottomObjects CONSTANT)
+
+    // Resolve circular dependency for QObject* properties in both classes
+    Q_MOC_INCLUDE("resources/AbstractResourcesBackend.h")
+
 public:
     /**
      * This describes the state of the resource
@@ -187,7 +216,6 @@ public:
     virtual QString status();
 
     AbstractResourcesBackend *backend() const;
-    QObject *backendObject() const;
 
     /**
      * @returns a name sort key for faster sorting
@@ -199,8 +227,7 @@ public:
      *
      * @returns the rating for the resource or null if not available
      */
-    Rating *rating() const;
-    QVariant ratingVariant() const;
+    virtual Rating rating() const;
 
     bool categoryMatches(Category *cat);
 
@@ -240,6 +267,15 @@ public:
     virtual QString contentRatingDescription() const;
     virtual uint contentRatingMinimumAge() const;
 
+    /**
+     * @returns List of component URLs to display at the top of application page.
+     */
+    virtual QStringList topObjects() const;
+    /**
+     * @returns List of component URLs to display at the bottom of application page.
+     */
+    virtual QStringList bottomObjects() const;
+
 public Q_SLOTS:
     virtual void fetchScreenshots();
     virtual void fetchChangelog() = 0;
@@ -258,8 +294,7 @@ Q_SIGNALS:
     void versionsChanged();
 
     /// response to the fetchScreenshots method
-    ///@p thumbnails and @p screenshots should have the same number of elements
-    void screenshotsFetched(const QList<QUrl> &thumbnails, const QList<QUrl> &screenshots);
+    void screenshotsFetched(const Screenshots &screenshots);
     void changelogFetched(const QString &changelog);
 
 private:
